Overview
========

This distribution used to contain a full text indexing facility for
Zope 2 and more specifically for Products.ZCatalog.

The code was moved directly into the Products.ZCatalog distribution,
leaving behind an empty distribution shell.
